# Generated by Django 5.2.4 on 2025-08-04 19:56

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('netbox_bgp', '0034_aspathlist_routingpolicyrule_match_aspath_list_and_more'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='aspathlist',
            options={'ordering': ['name']},
        ),
        migrations.AlterModelOptions(
            name='aspathlistrule',
            options={'ordering': ('aspath_list', 'index')},
        ),
        migrations.AlterModelOptions(
            name='bgppeergroup',
            options={'ordering': ['name']},
        ),
        migrations.AlterModelOptions(
            name='bgpsession',
            options={'ordering': ['name']},
        ),
        migrations.AlterModelOptions(
            name='community',
            options={'ordering': ['value']},
        ),
        migrations.AlterModelOptions(
            name='communitylist',
            options={'ordering': ['name']},
        ),
        migrations.AlterModelOptions(
            name='communitylistrule',
            options={'ordering': ['community_list', 'community']},
        ),
        migrations.AlterModelOptions(
            name='prefixlist',
            options={'ordering': ['name']},
        ),
        migrations.AlterModelOptions(
            name='prefixlistrule',
            options={'ordering': ['prefix_list', 'index']},
        ),
        migrations.AlterModelOptions(
            name='routingpolicy',
            options={'ordering': ['name']},
        ),
        migrations.AlterModelOptions(
            name='routingpolicyrule',
            options={'ordering': ['routing_policy', 'index']},
        ),
    ]
