# Generated by Django 5.2.9 on 2026-01-20 18:18

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("netbox_bgp", "0037_alter_bgpsession_options"),
    ]

    operations = [
        migrations.AddField(
            model_name="bgpsession",
            name="max_prefixes",
            field=models.PositiveIntegerField(
                blank=True,
                null=True,
                validators=[django.core.validators.MinValueValidator(1)],
            ),
        ),
    ]
