# Generated by Django 5.2.5 on 2025-09-29 20:34

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('netbox_bgp', '0035_alter_aspathlist_options_and_more'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='routingpolicy',
            options={'ordering': ['weight', 'name']},
        ),
        migrations.AddField(
            model_name='routingpolicy',
            name='weight',
            field=models.PositiveIntegerField(blank=True, null=True),
        ),
    ]
