{% load helpers %}

<div class="card">
    <h5 class="card-header">
        Related BGP Sessions
    </h5>
    <div class="card-body">
        {% htmx_table 'plugins:netbox_bgp:bgpsession_list' device_id=object.id %}
    </div>
</div>
