# Generated by Django 5.2.9 on 2025-12-16 23:52

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('netbox_bgp', '0036_alter_routingpolicy_options_routingpolicy_weight'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='bgpsession',
            options={'ordering': ('name', 'pk')},
        ),
    ]
