# Generated by Django 5.2.9 on 2026-02-13 13:14

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("netbox_bgp", "0038_bgpsession_max_prefix"),
    ]

    operations = [
        migrations.AddField(
            model_name="bgpsession",
            name="remote_as_macro",
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
    ]
